Crate fsmentry_core

Crate fsmentry_core 

A code generator for state machines with an entry API.

See the fsmentry crate.

Structs

FsmEntry
A Parse-able and printable representation of a state machine.
Mermaid
A Renderer which embeds a script to load mermaidjs into the docs.

Traits

Renderer
Renderer for mermaid diagrams.